@@ -336,7 +336,7 @@ class DcsConnection:
         logging.info(str(id(self)) + " TID: " + str(tid) + "; Unknown MSG-Type received: " + str(msgtype) + ".")
     
     def watchdog(self):
-        logging.debug(str(id(self)) + " DCS-Watchdog running...")
+        logging.info(str(id(self)) + " DCS-Watchdog running...")
         with self.__threadLock__:
             if(self.__running__ != True):
                 logging.warning(str(id(self)) + "DCS-Connection ist stopped.")
@@ -777,7 +777,7 @@ class DcsConnection:
         if self.__logDataTimestamp__ != None:
             difference = datetime.now() - self.__logDataTimestamp__
             if(difference.total_seconds() < LOGDATABLOCKTIME): 
-                logging.debug(str(id(self)) + " cannot get logdata. Minimum waiting time not reached. " + str(difference.total_seconds()))
+                logging.warning(str(id(self)) + " cannot get logdata. Minimum waiting time not reached. " + str(difference.total_seconds()))
                 raise Exception("Logdata not ready.")
 
         t = datetime.now()
@@ -842,30 +842,30 @@ if __name__ == "__main__":
     cryptoKeyInvalid = "ABABABABABABAB00ABABABABABABAB00"
     server = "my-pv.live"
 
-    if True:
-        connection = DcsConnection(serial, cryptoKey, server, 50333)
-        connection2 = DcsConnection(serial2, cryptoKey, server, 50333)
-        connection.connect()
-        connection2.connect()
-        hash1 = connection.getsockethash()
-        hash2 = connection2.getsockethash()
-        try:
-            while True:
-                print(color('[DCS-Connection] Communication active. Press CTRL+C to stop', fore='blue', style='bright'))
-                # connection.watchdog()
-                # connection2.watchdog()
-                if(hash1 != connection.getsockethash()):
-                    print(color('[DCS-Connection] Socket of serial ' + str(serial) + ' has changed.', fore='red', style='bright'))
-                    hash1 = connection.getsockethash()
-                if(hash2 != connection2.getsockethash()):
-                    print(color('[DCS-Connection] Socket of serial ' + str(serial2) + ' has changed.', fore='red', style='bright'))
-                    hash2 = connection2.getsockethash()
+    # if True:
+    #     connection = DcsConnection(serial, cryptoKey, server, 50333)
+    #     connection2 = DcsConnection(serial2, cryptoKey, server, 50333)
+    #     connection.connect()
+    #     connection2.connect()
+    #     hash1 = connection.getsockethash()
+    #     hash2 = connection2.getsockethash()
+    #     try:
+    #         while True:
+    #             print(color('[DCS-Connection] Communication active. Press CTRL+C to stop', fore='blue', style='bright'))
+    #             connection.watchdog()
+    #             connection2.watchdog()
+    #             if(hash1 != connection.getsockethash()):
+    #                 print(color('[DCS-Connection] Socket of serial ' + str(serial) + ' has changed.', fore='red', style='bright'))
+    #                 hash1 = connection.getsockethash()
+    #             if(hash2 != connection2.getsockethash()):
+    #                 print(color('[DCS-Connection] Socket of serial ' + str(serial2) + ' has changed.', fore='red', style='bright'))
+    #                 hash2 = connection2.getsockethash()
 
-                time.sleep(10)
-        except KeyboardInterrupt as e:
-            print("[DCS-Connection] Stopping Test...")
-            connection.disconnect()
-            connection2.disconnect()
+    #             time.sleep(10)
+    #     except KeyboardInterrupt as e:
+    #         print("[DCS-Connection] Stopping Test...")
+    #         connection.disconnect()
+    #         connection2.disconnect()
 
     #AUTO-Tests
     #Constructor Tests
@@ -1059,6 +1059,8 @@ if __name__ == "__main__":
         print(color('ERROR: sending data.', fore='red', style='bright'))
 
     try:
+        print("waiting...")
+        time.sleep(LOGDATABLOCKTIME)
         connection.loadlogdata()
         connection.clearlogdata()
         connection.sendlogdata()
@@ -1066,6 +1068,12 @@ if __name__ == "__main__":
     except Exception as e:
         print(color('ERROR: sending logData.', fore='red', style='bright'))
 
+    try:
+        connection.loadlogdata()
+        print(color('ERROR: getting logData to without waiting.', fore='red', style='bright'))
+    except Exception as e:
+        print(color('SUCCESS: getting logData to without waiting.', fore='green', style='bright'))
+
     try:
         connection.sendsetup()
         print(color('SUCCESS: sending setup.', fore='green', style='bright'))
